exceptiontools.ImpreciseTempoError
==================================

.. inheritance-diagram:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
